Testing Javascript

# Type Stuff

Key Up:
Key Down:
Key Press:
Change:

Change the page title!

No href

Update a div

What's for dinner?

Click for the mouse down event

Here's some text

Click for the mouse up event

Click for the mouse click event

Click to show button

Clicking this causes a JS exception in the click handler
Toggle checkbox

A paragraph suppressed using CSS display=none

Displayed

Display set to none

Hidden

ok
Check box you can't see

A sub-element that is explicitly visible using CSS visibility=visible

This should be greenish

- So should this
- But this is red

Close window

I should be deleted when you click my containing div

Whereas, I should not

Click to hide me.
Click actions delayed by 3000ms:
Click to show black box
Click to hide black box
Click me to open a new window Mouse over me will throw a JS error
Click on me to show the related target